@@ -269,7 +269,7 @@ class baseline_model():
             acc_score= (accuracy_score(y_test,predictions))
             roc_score= (roc_auc_score(y_test,predictions))
             f1_macro= (f1_score(y_test, predictions, average='macro'))
-            print("{:<15}| acc_score = {:.3f} | roc_score = {:,.3f} | f1_score(macro) = {:,.3f} | Training time = {:,.3f} | Pred. time = {:,.3f}".format(name, acc_score, roc_score, f1_macro, train_time, predict_time))
+            print("{:<15}| acc_score = {:.3f} | roc_score = {:,.3f} | f1_score(macro) = {:,.3f} | Train time = {:,.3f}s | Pred. time = {:,.3f}s".format(name, acc_score, roc_score, f1_macro, train_time, predict_time))
         
     def Regression_summary(self):
         print('Starting regression summary...')
@@ -327,7 +327,7 @@ class baseline_model():
             rmse = sqrt(mean_absolute_error(y_test, predictions))
             r2 = r2_score(y_test, predictions)
             
-            print("{:<15}| exp_var = {:.3f} | mae = {:,.3f} | rmse = {:,.3f} | r2 = {:,.3f} | Train time = {:,.3f} | Pred. time = {:,.3f}".format(name, exp_var, mae, rmse, r2, train_time, predict_time))
+            print("{:<15}| exp_var = {:.3f} | mae = {:,.3f} | rmse = {:,.3f} | r2 = {:,.3f} | Train time = {:,.3f}s | Pred. time = {:,.3f}s".format(name, exp_var, mae, rmse, r2, train_time, predict_time))
         
         print('------------------------NON LINEAR MODELS----------------------------------')
         print('---------------------THIS MIGHT TAKE A WHILE-------------------------------')
@@ -359,5 +359,5 @@ class baseline_model():
             rmse = sqrt(mean_absolute_error(y_test, predictions))
             r2 = r2_score(y_test, predictions)
             
-            print("{:<15}| exp_var = {:.3f} | mae = {:,.3f} | rmse = {:,.3f} | r2 = {:,.3f} | Train time = {:,.3f} | Pred. time = {:,.3f}".format(name, exp_var, mae, rmse, r2, train_time, predict_time))
+            print("{:<15}| exp_var = {:.3f} | mae = {:,.3f} | rmse = {:,.3f} | r2 = {:,.3f} | Train time = {:,.3f}s | Pred. time = {:,.3f}s".format(name, exp_var, mae, rmse, r2, train_time, predict_time))
         
\ No newline at end of file
